Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(656)

Unified Diff: components/mus/ws/event_dispatcher.h

Issue 1759273002: Add AcceleratorType to EventMatcher (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/public/interfaces/input_event_matcher.mojom ('k') | components/mus/ws/event_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/ws/event_dispatcher.h
diff --git a/components/mus/ws/event_dispatcher.h b/components/mus/ws/event_dispatcher.h
index 1f36fe604032af72e41d888b5383727939dcbbdc..432213e3b5143e7d6e47a968291975136c6fd26c 100644
--- a/components/mus/ws/event_dispatcher.h
+++ b/components/mus/ws/event_dispatcher.h
@@ -137,11 +137,13 @@ class EventDispatcher : public ServerWindowObserver {
// observer for a window if any pointer events are targeting it.
bool IsObservingWindow(ServerWindow* window);
- // Looks to see if there is an accelerator bound to the specified code/flags.
- // If there is one, sets |accelerator_id| to the id of the accelerator invoked
- // and returns true. If there is none, returns false so normal key event
- // processing can continue.
- bool FindAccelerator(const ui::KeyEvent& event, uint32_t* accelerator_id);
+ // Looks to see if there is an accelerator bound to the specified code/flags,
+ // and of the matching |phase|. If there is one, sets |accelerator_id| to the
+ // id of the accelerator invoked and returns true. If there is none, returns
+ // false so normal key event processing can continue.
+ bool FindAccelerator(const ui::KeyEvent& event,
+ const mojom::AcceleratorPhase phase,
+ uint32_t* accelerator_id);
// ServerWindowObserver:
void OnWillChangeWindowHierarchy(ServerWindow* window,
« no previous file with comments | « components/mus/public/interfaces/input_event_matcher.mojom ('k') | components/mus/ws/event_dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698